==> xdvik-22.74.1.tar.gz: xdvik-22.74.1/texk/xdvik/xaw_menu.h <==
/*
 * Copyright (c) 2001, 2002 xdvik project team
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * PAUL VOJTA OR ANY OTHER AUTHOR OF THIS SOFTWARE BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef XAW_MENU_H_
#define XAW_MENU_H_

#if !defined(MOTIF) && defined(BUTTONS)

extern void create_buttons(Widget menu_bar, int *ret_panel_width);
extern int get_panel_width(void);

extern void toggle_tick(Boolean val, Widget w);
extern void set_button_panel_height(XtArgVal);
extern void quit_confirm_callback(void);

extern void toggle_menu(int val, XtActionProc proc);
extern void xaw_create_pagelist(void);
/*  extern int xaw_get_button_width(void); */
extern void toggle_scrollbars(void);
extern void toggle_buttons(void);

#endif /* !defined(MOTIF) && defined(BUTTONS) */

#endif /* XAW_MENU_H_ */

==> xdvik-22.76.1.tar.gz: xdvik-22.76.1/texk/xdvik/xaw_menu.h <==
/*
 * Copyright (c) 2001, 2002 xdvik project team
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * PAUL VOJTA OR ANY OTHER AUTHOR OF THIS SOFTWARE BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef XAW_MENU_H_
#define XAW_MENU_H_

#if !defined(MOTIF) && defined(BUTTONS)

extern void create_menu_buttons(Widget menu_bar, int *ret_panel_width);
extern int get_panel_width(void);

extern void toggle_tick(Boolean val, Widget w);
extern void set_button_panel_height(XtArgVal);
extern void quit_confirm_callback(void);

extern void toggle_menu(int val, XtActionProc proc);
extern void xaw_create_pagelist(void);
/*  extern int xaw_get_button_width(void); */
extern void toggle_scrollbars(void);
extern void toggle_buttons(void);

#endif /* !defined(MOTIF) && defined(BUTTONS) */

#endif /* XAW_MENU_H_ */
